@@ -21,8 +21,9 @@ func (c *command) newStatementDeleteCommand() *cobra.Command {
 		RunE:              c.statementDelete,
 	}
 
+	pcmd.AddCloudFlag(cmd)
+	c.addRegionFlag(cmd)
 	pcmd.AddForceFlag(cmd)
-	c.addComputePoolFlag(cmd)
 	pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddContextFlag(cmd, c.CLICommand)
 
