@@ -1,7 +1,6 @@
 package schemaregistry
 
 import (
-	"context"
 	"os"
 	"strings"
 
@@ -10,7 +9,7 @@ import (
 	srsdk "github.com/confluentinc/schema-registry-sdk-go"
 
 	pcmd "github.com/confluentinc/cli/internal/pkg/cmd"
-	"github.com/confluentinc/cli/internal/pkg/errors"
+	v1 "github.com/confluentinc/cli/internal/pkg/config/v1"
 	"github.com/confluentinc/cli/internal/pkg/examples"
 	"github.com/confluentinc/cli/internal/pkg/output"
 )
@@ -19,32 +18,47 @@ type validateOut struct {
 	IsCompatible bool `human:"Compatible" serialized:"is_compatible"`
 }
 
-func (c *command) newCompatibilityValidateCommand() *cobra.Command {
+func (c *command) newCompatibilityValidateCommand(cfg *v1.Config) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "validate",
 		Short: "Validate a schema with a subject version.",
 		Long:  "Validate that a schema is compatible against a given subject version.",
 		Args:  cobra.NoArgs,
 		RunE:  c.compatibilityValidate,
-		Example: examples.BuildExampleString(
-			examples.Example{
-				Text: `Validate the compatibility of schema "payments" against the latest version of subject "records".`,
-				Code: "confluent schema-registry compatibility validate --schema payments.avro --type avro --subject records --version latest",
-			},
-		),
 	}
 
-	cmd.Flags().String("subject", "", SubjectUsage)
-	cmd.Flags().String("version", "", `Version of the schema. Can be a specific version or "latest".`)
+	example := examples.Example{
+		Text: `Validate the compatibility of schema "payments" against the latest version of subject "records".`,
+		Code: "confluent schema-registry compatibility validate --schema payments.avsc --type avro --subject records --version latest",
+	}
+	if cfg.IsOnPremLogin() {
+		example.Code += " " + onPremAuthenticationMsg
+	}
+	cmd.Example = examples.BuildExampleString(example)
+
 	cmd.Flags().String("schema", "", "The path to the schema file.")
 	pcmd.AddSchemaTypeFlag(cmd)
+	cmd.Flags().String("subject", "", subjectUsage)
+	cmd.Flags().String("version", "", `Version of the schema. Can be a specific version or "latest".`)
 	cmd.Flags().String("references", "", "The path to the references file.")
-	pcmd.AddApiKeyFlag(cmd, c.AuthenticatedCLICommand)
-	pcmd.AddApiSecretFlag(cmd)
 	pcmd.AddContextFlag(cmd, c.CLICommand)
-	pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
+	if cfg.IsCloudLogin() {
+		pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
+	} else {
+		cmd.Flags().AddFlagSet(pcmd.OnPremSchemaRegistrySet())
+	}
 	pcmd.AddOutputFlag(cmd)
 
+	if cfg.IsCloudLogin() {
+		// Deprecated
+		pcmd.AddApiKeyFlag(cmd, c.AuthenticatedCLICommand)
+		cobra.CheckErr(cmd.Flags().MarkHidden("api-key"))
+
+		// Deprecated
+		pcmd.AddApiSecretFlag(cmd)
+		cobra.CheckErr(cmd.Flags().MarkHidden("api-secret"))
+	}
+
 	cobra.CheckErr(cmd.MarkFlagFilename("schema", "avsc", "json", "proto"))
 	cobra.CheckErr(cmd.MarkFlagFilename("references", "json"))
 
@@ -52,19 +66,11 @@ func (c *command) newCompatibilityValidateCommand() *cobra.Command {
 }
 
 func (c *command) compatibilityValidate(cmd *cobra.Command, args []string) error {
-	srClient, ctx, err := getApiClient(cmd, c.Config, c.Version)
-	if err != nil {
-		return err
-	}
-
-	return validateSchemaCompatibility(cmd, srClient, ctx)
-}
-
-func validateSchemaCompatibility(cmd *cobra.Command, srClient *srsdk.APIClient, ctx context.Context) error {
 	subject, err := cmd.Flags().GetString("subject")
 	if err != nil {
 		return err
 	}
+
 	version, err := cmd.Flags().GetString("version")
 	if err != nil {
 		return err
@@ -86,19 +92,28 @@ func validateSchemaCompatibility(cmd *cobra.Command, srClient *srsdk.APIClient,
 		return err
 	}
 
-	refs, err := ReadSchemaRefs(cmd)
+	references, err := ReadSchemaReferences(cmd)
 	if err != nil {
 		return err
 	}
 
-	req := srsdk.RegisterSchemaRequest{Schema: string(schema), SchemaType: schemaType, References: refs}
-
-	compatibilityCheck, httpResp, err := srClient.DefaultApi.TestCompatibilityBySubjectName(ctx, subject, version, req, nil)
+	client, err := c.GetSchemaRegistryClient()
 	if err != nil {
-		return errors.CatchSchemaNotFoundError(err, httpResp)
+		return err
+	}
+
+	req := srsdk.RegisterSchemaRequest{
+		Schema:     string(schema),
+		SchemaType: schemaType,
+		References: references,
+	}
+
+	res, err := client.TestCompatibilityBySubjectName(subject, version, req)
+	if err != nil {
+		return catchSchemaNotFoundError(err, subject, version)
 	}
 
 	table := output.NewTable(cmd)
-	table.Add(&validateOut{IsCompatible: compatibilityCheck.IsCompatible})
+	table.Add(&validateOut{IsCompatible: res.IsCompatible})
 	return table.Print()
 }
