@@ -1,62 +1,71 @@
 package schemaregistry
 
 import (
-	"context"
-	"fmt"
-
 	"github.com/spf13/cobra"
 
 	srsdk "github.com/confluentinc/schema-registry-sdk-go"
 
 	pcmd "github.com/confluentinc/cli/internal/pkg/cmd"
+	v1 "github.com/confluentinc/cli/internal/pkg/config/v1"
 	"github.com/confluentinc/cli/internal/pkg/errors"
 	"github.com/confluentinc/cli/internal/pkg/examples"
 	"github.com/confluentinc/cli/internal/pkg/output"
 	"github.com/confluentinc/cli/internal/pkg/properties"
 	"github.com/confluentinc/cli/internal/pkg/resource"
-	pversion "github.com/confluentinc/cli/internal/pkg/version"
 )
 
-func (c *command) newExporterCreateCommand() *cobra.Command {
+func (c *command) newExporterCreateCommand(cfg *v1.Config) *cobra.Command {
 	cmd := &cobra.Command{
-		Use:   "create <name>",
-		Short: "Create a new schema exporter.",
-		Args:  cobra.ExactArgs(1),
-		RunE:  c.exporterCreate,
-		Example: examples.BuildExampleString(
-			examples.Example{
-				Text: "Create a new schema exporter.",
-				Code: fmt.Sprintf(`%s schema-registry exporter create my-exporter --config-file config.txt --subjects my-subject1,my-subject2 --subject-format my-\${subject} --context-type CUSTOM --context-name my-context`, pversion.CLIName),
-			},
-		),
+		Use:     "create <name>",
+		Short:   "Create a new schema exporter.",
+		Args:    cobra.ExactArgs(1),
+		RunE:    c.exporterCreate,
+		Example: examples.BuildExampleString(),
 	}
 
+	example := examples.Example{
+		Text: "Create a new schema exporter.",
+		Code: `confluent schema-registry exporter create my-exporter --config-file config.txt --subjects my-subject1,my-subject2 --subject-format my-\${subject} --context-type CUSTOM --context-name my-context`,
+	}
+	if cfg.IsOnPremLogin() {
+		example.Code += " " + onPremAuthenticationMsg
+	}
+	cmd.Example = examples.BuildExampleString(example)
+
 	cmd.Flags().String("config-file", "", "Exporter configuration file.")
 	cmd.Flags().StringSlice("subjects", []string{"*"}, "A comma-separated list of exporter subjects.")
 	cmd.Flags().String("subject-format", "${subject}", "Exporter subject rename format. The format string can contain ${subject}, which will be replaced with the default subject name.")
 	addContextTypeFlag(cmd)
 	cmd.Flags().String("context-name", "", "Exporter context name.")
-	pcmd.AddApiKeyFlag(cmd, c.AuthenticatedCLICommand)
-	pcmd.AddApiSecretFlag(cmd)
 	pcmd.AddContextFlag(cmd, c.CLICommand)
-	pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
+	if cfg.IsCloudLogin() {
+		pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
+	} else {
+		cmd.Flags().AddFlagSet(pcmd.OnPremSchemaRegistrySet())
+	}
 	pcmd.AddOutputFlag(cmd)
 
+	if cfg.IsCloudLogin() {
+		// Deprecated
+		pcmd.AddApiKeyFlag(cmd, c.AuthenticatedCLICommand)
+		cobra.CheckErr(cmd.Flags().MarkHidden("api-key"))
+
+		// Deprecated
+		pcmd.AddApiSecretFlag(cmd)
+		cobra.CheckErr(cmd.Flags().MarkHidden("api-secret"))
+	}
+
 	cobra.CheckErr(cmd.MarkFlagRequired("config-file"))
 
 	return cmd
 }
 
 func (c *command) exporterCreate(cmd *cobra.Command, args []string) error {
-	srClient, ctx, err := getApiClient(cmd, c.Config, c.Version)
+	client, err := c.GetSchemaRegistryClient()
 	if err != nil {
 		return err
 	}
 
-	return createExporter(cmd, args[0], srClient, ctx)
-}
-
-func createExporter(cmd *cobra.Command, name string, srClient *srsdk.APIClient, ctx context.Context) error {
 	subjects, err := cmd.Flags().GetStringSlice("subjects")
 	if err != nil {
 		return err
@@ -96,7 +105,7 @@ func createExporter(cmd *cobra.Command, name string, srClient *srsdk.APIClient,
 	}
 
 	req := srsdk.CreateExporterRequest{
-		Name:                name,
+		Name:                args[0],
 		Subjects:            subjects,
 		SubjectRenameFormat: subjectFormat,
 		ContextType:         contextType,
@@ -104,10 +113,10 @@ func createExporter(cmd *cobra.Command, name string, srClient *srsdk.APIClient,
 		Config:              configMap,
 	}
 
-	if _, _, err := srClient.DefaultApi.CreateExporter(ctx, req); err != nil {
+	if _, err := client.CreateExporter(req); err != nil {
 		return err
 	}
 
-	output.Printf(errors.CreatedResourceMsg, resource.SchemaExporter, name)
+	output.Printf(errors.CreatedResourceMsg, resource.SchemaExporter, args[0])
 	return nil
 }
