@@ -1,14 +1,12 @@
 package schemaregistry
 
 import (
-	"context"
 	"strconv"
 
 	"github.com/spf13/cobra"
 
-	srsdk "github.com/confluentinc/schema-registry-sdk-go"
-
 	pcmd "github.com/confluentinc/cli/internal/pkg/cmd"
+	v1 "github.com/confluentinc/cli/internal/pkg/config/v1"
 	"github.com/confluentinc/cli/internal/pkg/output"
 )
 
@@ -20,7 +18,7 @@ type getStatusOut struct {
 	ErrorTrace string `human:"Error Trace" serialized:"error_trace"`
 }
 
-func (c *command) newExporterGetStatusCommand() *cobra.Command {
+func (c *command) newExporterGetStatusCommand(cfg *v1.Config) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "get-status <name>",
 		Short: "Get the status of the schema exporter.",
@@ -28,26 +26,34 @@ func (c *command) newExporterGetStatusCommand() *cobra.Command {
 		RunE:  c.exporterGetStatus,
 	}
 
-	pcmd.AddApiKeyFlag(cmd, c.AuthenticatedCLICommand)
-	pcmd.AddApiSecretFlag(cmd)
 	pcmd.AddContextFlag(cmd, c.CLICommand)
-	pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
+	if cfg.IsCloudLogin() {
+		pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
+	} else {
+		cmd.Flags().AddFlagSet(pcmd.OnPremSchemaRegistrySet())
+	}
 	pcmd.AddOutputFlag(cmd)
 
+	if cfg.IsCloudLogin() {
+		// Deprecated
+		pcmd.AddApiKeyFlag(cmd, c.AuthenticatedCLICommand)
+		cobra.CheckErr(cmd.Flags().MarkHidden("api-key"))
+
+		// Deprecated
+		pcmd.AddApiSecretFlag(cmd)
+		cobra.CheckErr(cmd.Flags().MarkHidden("api-secret"))
+	}
+
 	return cmd
 }
 
 func (c *command) exporterGetStatus(cmd *cobra.Command, args []string) error {
-	srClient, ctx, err := getApiClient(cmd, c.Config, c.Version)
+	client, err := c.GetSchemaRegistryClient()
 	if err != nil {
 		return err
 	}
 
-	return getExporterStatus(cmd, args[0], srClient, ctx)
-}
-
-func getExporterStatus(cmd *cobra.Command, name string, srClient *srsdk.APIClient, ctx context.Context) error {
-	status, _, err := srClient.DefaultApi.GetExporterStatus(ctx, name)
+	status, err := client.GetExporterStatus(args[0])
 	if err != nil {
 		return err
 	}
