@@ -10,8 +10,6 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/stretchr/testify/require"
 
-	ccloudv1 "github.com/confluentinc/ccloud-sdk-go-v1-public"
-	ccloudv1mock "github.com/confluentinc/ccloud-sdk-go-v1-public/mock"
 	cmkv2 "github.com/confluentinc/ccloud-sdk-go-v2/cmk/v2"
 	cmkmock "github.com/confluentinc/ccloud-sdk-go-v2/cmk/v2/mock"
 
@@ -65,11 +63,11 @@ func TestFindKafkaCluster_Expired(t *testing.T) {
 					},
 					GetCmkV2ClusterExecuteFunc: func(_ cmkv2.ApiGetCmkV2ClusterRequest) (cmkv2.CmkV2Cluster, *http.Response, error) {
 						cluster := cmkv2.CmkV2Cluster{
-							Id: stringPtr("lkc-123456"),
+							Id: cmkv2.PtrString("lkc-123456"),
 							Spec: &cmkv2.CmkV2ClusterSpec{
-								DisplayName:            stringPtr(""),
-								KafkaBootstrapEndpoint: stringPtr(""),
-								HttpEndpoint:           stringPtr(""),
+								DisplayName:            cmkv2.PtrString(""),
+								KafkaBootstrapEndpoint: cmkv2.PtrString(""),
+								HttpEndpoint:           cmkv2.PtrString(""),
 							},
 						}
 						return cluster, nil, nil
@@ -84,12 +82,7 @@ func TestFindKafkaCluster_Expired(t *testing.T) {
 	require.True(t, config.LastUpdate.After(update))
 }
 
-func stringPtr(s string) *string {
-	return &s
-}
-
 func TestDynamicContext_ParseFlagsIntoContext(t *testing.T) {
-	client := buildCcloudMockClient()
 	tests := []struct {
 		name           string
 		ctx            *DynamicContext
@@ -136,7 +129,7 @@ func TestDynamicContext_ParseFlagsIntoContext(t *testing.T) {
 		require.NoError(t, err)
 		initialEnvId := test.ctx.GetCurrentEnvironment()
 		initialActiveKafkaId := test.ctx.KafkaClusterContext.GetActiveKafkaClusterId()
-		err = test.ctx.ParseFlagsIntoContext(cmd, client)
+		err = test.ctx.ParseFlagsIntoContext(cmd)
 		require.NoError(t, err)
 		finalEnv := test.ctx.GetCurrentEnvironment()
 		finalCluster := test.ctx.KafkaClusterContext.GetActiveKafkaClusterId()
@@ -153,14 +146,6 @@ func TestDynamicContext_ParseFlagsIntoContext(t *testing.T) {
 	}
 }
 
-func buildCcloudMockClient() *ccloudv1.Client {
-	client := pmock.NewClientMock()
-	client.Account = &ccloudv1mock.AccountInterface{ListFunc: func(_ *ccloudv1.Account) ([]*ccloudv1.Account, error) {
-		return []*ccloudv1.Account{{Id: apiEnvironment}}, nil
-	}}
-	return client
-}
-
 func getBaseContext() *DynamicContext {
 	cfg := v1.AuthenticatedCloudConfigMock()
 	return NewDynamicContext(cfg.Context(), pmock.NewV2ClientMock())
