@@ -121,8 +121,22 @@ func catchCCloudTokenErrors(err error) error {
 
 func catchOpenAPIError(err error) error {
 	if openAPIError, ok := err.(srsdk.GenericOpenAPIError); ok {
-		return New(string(openAPIError.Body()))
+		body := string(openAPIError.Body())
+
+		r := strings.NewReader(body)
+
+		formattedErr := &struct {
+			ErrorCode int    `json:"error_code"`
+			Message   string `json:"message"`
+		}{}
+
+		if err := json.NewDecoder(r).Decode(formattedErr); err == nil {
+			return New(formattedErr.Message)
+		}
+
+		return New(body)
 	}
+
 	return err
 }
 
@@ -143,11 +157,7 @@ func catchCCloudBackendUnmarshallingError(err error) error {
 */
 
 func CatchCCloudV2Error(err error, r *http.Response) error {
-	if err == nil {
-		return nil
-	}
-
-	if r == nil {
+	if err == nil || r == nil {
 		return err
 	}
 
@@ -325,25 +335,6 @@ func isResourceNotFoundError(err error) bool {
 	return strings.Contains(err.Error(), "resource not found")
 }
 
-/*
-error creating topic bob: Topic 'bob' already exists.
-*/
-func CatchTopicExistsError(err error, clusterId string, topicName string, ifNotExistsFlag bool) error {
-	if err == nil {
-		return nil
-	}
-	compiledRegex := regexp.MustCompile(`error creating topic .*: Topic '.*' already exists\.`)
-	if compiledRegex.MatchString(err.Error()) {
-		if ifNotExistsFlag {
-			return nil
-		}
-		errorMsg := fmt.Sprintf(TopicExistsErrorMsg, topicName, clusterId)
-		suggestions := fmt.Sprintf(TopicExistsSuggestions, clusterId, clusterId)
-		return NewErrorWithSuggestions(errorMsg, suggestions)
-	}
-	return err
-}
-
 /*
 failed to produce offset -1: Unknown error, how did this happen? Error code = 87
 */
@@ -358,35 +349,3 @@ func CatchProduceToCompactedTopicError(err error, topicName string) (bool, error
 	}
 	return false, err
 }
-
-func CatchSchemaNotFoundError(err error, r *http.Response) error {
-	if err == nil {
-		return nil
-	}
-
-	if r == nil {
-		return err
-	}
-
-	if strings.Contains(r.Status, "Not Found") {
-		return NewErrorWithSuggestions(SchemaNotFoundErrorMsg, SchemaNotFoundSuggestions)
-	}
-
-	return err
-}
-
-func CatchNoSubjectLevelConfigError(err error, r *http.Response, subject string) error {
-	if err == nil {
-		return nil
-	}
-
-	if r == nil {
-		return err
-	}
-
-	if strings.Contains(r.Status, "Not Found") {
-		return errors.New(fmt.Sprintf(NoSubjectLevelConfigErrorMsg, subject))
-	}
-
-	return err
-}
