@@ -24,10 +24,10 @@ func fixturePath(t *testing.T, fixture string) string {
 	return filepath.Join(filepath.Dir(filename), "fixtures", "output", fixture)
 }
 
-func getInputFixturePath(t *testing.T, directoryName string, file string) string {
+func getInputFixturePath(directoryName string, file string) string {
 	_, callerFileName, _, ok := runtime.Caller(0)
 	if !ok {
-		t.Fatalf("problems recovering caller information")
+		panic("problems recovering caller information")
 	}
 	return filepath.Join(filepath.Dir(callerFileName), "fixtures", "input", directoryName, file)
 }
